import requests
import json
import argparse
import sys



parser = argparse.ArgumentParser(description='Gitlab Release Uploader')
parser.add_argument('--privateToken', '-p', help='Private token to access Gitlab', required=True)
parser.add_argument('--projectId', '-i', help='ProjectID of the related project', required=True)
parser.add_argument('--projectUrl', '-u', help='URL of the related project at Gitlab', required=True)
parser.add_argument('--file', '-f', help='File to be released', required=True)
parser.add_argument('--releaseName', '-n', help='Name of the release', required=True)
parser.add_argument('--releaseTag', '-t', help='Tag of the release in the repo, make sure it already exists', required=True)
parser.add_argument('--description', '-d', help='Description of the release', required=True)
args = parser.parse_args()
print(args)

privateToken = args.privateToken
projectId = args.projectId
projectUrl = args.projectUrl
fileToUpload = args.file
releaseName = args.releaseName
releaseTag = args.releaseTag
releaseDescription = args.description



uploadUrl = "https://gitlab.com/api/v4/projects/%s/uploads" % projectId
createReleaseUrl = "https://gitlab.com/api/v4/projects/%s/releases" % projectId


headers = { "PRIVATE-TOKEN" : privateToken}

files = {"file": open(fileToUpload, 'rb')}

uploadResult = requests.post(uploadUrl, files=files, headers=headers)
print(uploadResult)
print(uploadResult.text)
if uploadResult.status_code != 201:
  raise Exception('Unable to upload file to Gitlab')


uploadResultJson = json.loads(uploadResult.text)

fullUrl = projectUrl + uploadResultJson['url']

payloadCreateRelease = {
  "name": releaseName,
  "tag_name": releaseTag,
  "description": releaseDescription,
  "assets": {
    "links": [
      {
        "name": fileToUpload,
        "url": fullUrl
      }
    ]
  }
}

headers = { "PRIVATE-TOKEN" : privateToken, "Content-Type": "application/json"}

createReleaseResult = requests.post(createReleaseUrl, headers=headers, data=json.dumps(payloadCreateRelease))
print(createReleaseResult)
print(createReleaseResult.text)
if createReleaseResult.status_code != 201:
  raise Exception('Unable to create release')

